@@ -179,11 +179,21 @@ class LIB:
             return df
 
     @staticmethod
-    def get_parametro_valor(df, value) -> list:
-        result = []
+    def get_parametro_valor(df, value) -> str:
+        result = None
         try:
-            result.append(df.loc[df["nom_variavel"] == value].index[0])
-            result.append(df.loc[result[0], "val_parametro"])
+            index = df.loc[df["nom_variavel"] == value].index[0]
+            result = df.loc[index, "val_parametro"]
+        except Exception as error:
+            result = None
+        finally:
+            return result
+
+    @staticmethod
+    def get_parametro_valor_index(df, value) -> int:
+        result = None
+        try:
+            result = df.loc[df["nom_variavel"] == value].index[0]
         except Exception as error:
             result = None
         finally:
